@@ -7,7 +7,7 @@ import sys
 
 # The files() API was added in Python 3.9.
 if sys.version_info >= (3, 9):  # pragma: no cover
-    import importlib.resources as resources
+    from importlib import resources
 else:  # pragma: no cover
     import importlib_resources as resources
 
@@ -188,7 +188,7 @@ def uniq(container):
         sliced = itertools.islice(sort, 1, None)
 
         for i, j in zip(sort, sliced):
-            if _sequence_equal(i, j):
+            if equal(i, j):
                 return False
 
     except (NotImplementedError, TypeError):
